@@ -1,3 +1,25 @@
+# Copyright (C) 2019- Centre of Biological Engineering,
+#     University of Minho, Portugal
+
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+"""
+##############################################################################
+Optimization Problems for ETFL models
+
+Author: Vitor Pereira
+##############################################################################
+"""
 import logging
 import itertools
 
@@ -225,6 +247,8 @@ class ETFLGOUProblem(AbstractOUProblem):
         """
         gr_constraints = dict()
         reference = self.reference
+        if self._partial_solution:
+            candidate.update(self._partial_solution)
         if self.twostep:
             try:
                 deletions = {rxn: lv for rxn, lv in candidate.items() if lv == 0}
