@@ -1,6 +1,36 @@
+# Copyright (C) 2019- Centre of Biological Engineering,
+#     University of Minho, Portugal
+
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+
+"""
+##############################################################################
+Problems targeting modifications of reaction fluxes. The modifications are
+implemented changing the reaction bounds.
+
+Author: Vitor Pereira 
+##############################################################################
+"""
 import numpy as np
 from .problem import AbstractKOProblem, AbstractOUProblem
 from ..simulation import SStatus
+from typing import Union, TYPE_CHECKING, List
+
+if TYPE_CHECKING:
+    from cobra.core import Model
+    from reframed.core.cbmodel import CBModel
+    from mewpy.optimization.evaluation import EvaluationFunction
 
 
 class RKOProblem(AbstractKOProblem):
@@ -22,7 +52,10 @@ class RKOProblem(AbstractKOProblem):
 
     """
 
-    def __init__(self, model, fevaluation=None, **kwargs):
+    def __init__(self,
+                 model: Union["Model", "CBModel"],
+                 fevaluation: List["EvaluationFunction"] = None,
+                 **kwargs):
         super(RKOProblem, self).__init__(
             model, fevaluation=fevaluation, **kwargs)
 
@@ -63,7 +96,10 @@ class ROUProblem(AbstractOUProblem):
     :param boolean twostep: If deletions should be applied before identifiying reference flux values.
     """
 
-    def __init__(self, model, fevaluation=None, **kwargs):
+    def __init__(self,
+                 model: Union["Model", "CBModel"],
+                 fevaluation: List["EvaluationFunction"] = None,
+                 **kwargs):
         super(ROUProblem, self).__init__(
             model, fevaluation=fevaluation, **kwargs)
 
@@ -129,7 +165,10 @@ class MediumProblem(AbstractOUProblem):
 
     """
 
-    def __init__(self, model, fevaluation=None, **kwargs):
+    def __init__(self,
+                 model: Union["Model", "CBModel"],
+                 fevaluation: List["EvaluationFunction"] = None,
+                 **kwargs):
         super(MediumProblem, self).__init__(
             model, fevaluation=fevaluation, **kwargs)
         self.levels = kwargs.get('levels', np.linspace(0, 10, 101))
