@@ -24,6 +24,7 @@ Author: Vítor Pereira
 import logging
 from collections import OrderedDict
 import numpy as np
+
 from cobra.core.model import Model
 from cobra.core.solution import Solution
 from cobra.flux_analysis import pfba, moma, room
@@ -63,6 +64,10 @@ class CobraModelContainer(ModelContainer):
         """The model identifier."""
         return self.model.id
 
+    @id.setter
+    def id(self,sid:str):
+        self.model.id=sid
+
     @property
     def reactions(self) -> List[str]:
         """The list of reaction identifiers"""
@@ -262,7 +267,21 @@ class Simulation(CobraModelContainer, Simulator):
         # if modifications on the envirenment are permited
         # during simulations
         self._allow_env_changes = False
-
+        self.biomass_reaction = None
+        try: 
+            self.biomass_reaction=list(self.objective.keys())[0]
+        except:
+            pass
+     
+    def copy(self):
+        """Retuns a copy of the Simulator instance."""
+        return Simulation(self.model.copy(), 
+                          envcond=self.environmental_conditions.copy(),
+                          constraints=self._constraints.copy(),
+                          reset_solver=self._reset_solver
+                          )
+                              
+    
     @property
     def environmental_conditions(self):
         return self._environmental_conditions.copy()
@@ -369,6 +388,7 @@ class Simulation(CobraModelContainer, Simulator):
         reaction.annotation = annotations
         if replace and rxn_id in self.reactions:
             self.remove_reaction(rxn_id)
+
         self.model.add_reactions([reaction])
         set_objective(self.model, {reaction: objective})
 
@@ -380,6 +400,28 @@ class Simulation(CobraModelContainer, Simulator):
         """
         self.model.remove_reactions([r_id])
 
+    def update_stoichiometry(self, rxn_id, stoichiometry):
+        """Updates the stoichiometry of a reaction by creating a 
+        new reaction with a same id and the new stoichiometry
+
+        :param rxn_id: Reaction identifier
+        :type rxn_id: str
+        :param stoichiometry: the new stoichiometry
+        :type stoichiometry: dict[str:float]
+        """
+        rxn = self.model.reactions.get_by_id(rxn_id)
+        objective = self.objective.get(rxn_id, 0)
+        self.add_reaction(rxn_id,
+                          name=rxn.name,
+                          stoichiometry=stoichiometry,
+                          lb=rxn.lower_bound,
+                          ub=rxn.upper_bound,
+                          gpr=rxn.gene_reaction_rule,
+                          annotations=rxn.annotation,
+                          objective=objective,
+                          replace=True)
+
+
     def get_uptake_reactions(self):
         """
         :returns: The list of uptake reactions.
@@ -467,9 +509,10 @@ class Simulation(CobraModelContainer, Simulator):
 
         """
         lb, ub = self.model.reactions.get_by_id(reaction_id).bounds
-        return lb if lb > -np.inf else ModelConstants.REACTION_LOWER_BOUND,\
-            ub if ub < np.inf else ModelConstants.REACTION_UPPER_BOUND
-
+        #return lb if lb > -np.inf else ModelConstants.REACTION_LOWER_BOUND,\
+        #    ub if ub < np.inf else ModelConstants.REACTION_UPPER_BOUND
+        return lb,ub
+    
     def set_reaction_bounds(self, reaction_id, lb, ub, track=True):
         """
         Sets the bounds for a given reaction.
@@ -862,17 +905,17 @@ class GeckoSimulation(Simulation):
         else:
             raise ValueError(f"Protein {protein} not founded.")
 
-    def set_Kcat(self, protein, reaction, kcat):
+    def set_Kcat(self, protein, reaction, invkcat):
         """Alters an enzyme kcat for a given reaction.
 
         :param protein: The protein identifier
         :type protein: str
         :param reaction: The reaction identifier
         :type reaction: str
-        :param kcat: The kcat value, a real positive value.
-        :type kcat: float
+        :param invkcat: The inverse kcat value, a real positive value.
+        :type invkcat: float
         """
-        if kcat <= 0:
+        if invkcat <= 0:
             raise ValueError('kcat value needs to be positive.')
 
         rxn = self.model.reactions.get_by_id(reaction)
@@ -882,7 +925,7 @@ class GeckoSimulation(Simulation):
                 m = met
                 break
         if met is not None:
-            rxn.metabolites[met]=kcat
+            rxn.subtract_metabolites({met: invkcat})
         else:
             LOGGER.warn(f'Could not identify {protein} ' 
                         f'protein specie in reaction {reaction}')
