@@ -13,6 +13,12 @@
 
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
+"""
+##############################################################################
+Escher
+Author: Vitor Pereira
+##############################################################################
+"""
 
 import random
 import string
