@@ -13,8 +13,11 @@
 
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
-""" Plotter 
+"""
+##############################################################################
+Plotter 
 Author: Vitor Pereira
+##############################################################################
 """
 import matplotlib
 import numpy as np
